import { setState } from '@/utils'
import { constantRouterMap, asyncRouterMap } from '@/router'

let filterPermissionRoutes = (routes, permissionPath) => {
  return routes.reduce((arr, route) => {
    if (route.meta && route.meta.public) {
      arr.push(route)
      return arr
    }
    let children = route.children
      ? route.children.reduce((cArr, cRoute) => {
          if ((cArr.meta && cArr.meta.public) || permissionPath.indexOf(cRoute.path) > -1) {
            // 主动设置public或者有菜单权限
            cArr.push(cRoute)
          }
          return cArr
        }, [])
      : []
    route.children = children
    children.length > 0 && arr.push(route)
    return arr
  }, [])
}

const router = {
  namespaced: true,
  state: {
    addRoutes: null,
    routes: null
  },
  mutations: {
    setState,
    setRoutes(state, routes) {
      state.addRoutes = routes
      state.routes = constantRouterMap.concat(routes)
    }
  },
  actions: {
    generateRouter({ state, commit, rootState }) {
      return new Promise((resolve) => {
        let permissionPath = Object.keys(rootState.user.userRoles.menuAuth)
        let routes = filterPermissionRoutes(asyncRouterMap, permissionPath)
        commit('setRoutes', routes)
        resolve()
      })
    }
  }
}

export default router
