import { setState } from '@/utils'
import userApi from '@/api/user'

const user = {
  namespaced: true,
  state: {
    userInfo: sessionStorage.getItem('ngStorage-currentUser') ? JSON.parse(sessionStorage.getItem('ngStorage-currentUser')) : '',
    userRoles: null
  },
  mutations: {
    setState
  },
  actions: {
    ssoLogin({ state, commit }, data) {
      return new Promise((resolve, reject) => {
        if (process.env.NODE_ENV === 'development' || process.env.NODE_ENV === 'test') {
          // 测试环境不支持sso，写死模拟
          let res = {
            account: 'admin',
            token:
              'eyJhbGciOiJIUzUxMiJ9.eyJzdWIiOiJhZG1pbiIsImV4cCI6MTYwNTU5MzY1OCwiaWF0IjoxNjA1NTA3MjU4fQ.ioIbtQBto1Fb3V576dknl0wZLrh9rJF9fOLgffep_61rXzZtU4ZKSvOEOl8jvyQl07FD5t8WPaSfG-6y2HmNJA',
            userId: '1',
            username: 'test-admin'
          }
          sessionStorage.setItem('ngStorage-currentUser', JSON.stringify(res))
          commit('setState', { userInfo: res })
          resolve()
        } else {
          userApi.ssoLogin(data).then((res) => {
            if (res) {
              sessionStorage.setItem('ngStorage-currentUser', JSON.stringify(res))
              commit('setState', { userInfo: res })
              resolve()
            } else {
              reject(res)
            }
          })
        }
      })
    },
    getUserRole({ state, commit }, data) {
      return new Promise((resolve, reject) => {
        userApi
          .getUserRole(data)
          .then((res) => {
            commit('setState', { userRoles: res.data })
            resolve()
          })
          .catch((err) => {
            reject(err)
          })
      })
    },
    jumpToLogin({ state }) {
      if (process.env.NODE_ENV === 'development') {
        return (location.href = location.origin + '?code=develop')
      }
      return new Promise((resolve) => {
        userApi.getSSOInfo().then((res) => {
          if (res.enable) {
            let href = res.ssoUrl + location.href
            // let href = res.ssoUrl + location.href
            location.href = href
          } else {
            // 不支持sso就去自己的登录
            location.href = location.origin + '/manage/#/login'
          }
        })
      })
    },
    ssoLogout({ commit }) {
      userApi.getSSOInfo().then((res) => {
        sessionStorage.setItem('ngStorage-currentUser', '')
        commit('setState', { userInfo: '' })
        if (res.enable) {
          let href = res.ssoLogoutUrl + location.href
          location.href = href
        } else {
          // 不支持sso就去自己的登录
          location.href = location.origin + '/manage/#/login'
        }
      })
    },
    pwdLogin({ commit }, data) {
      userApi.pwdLogin(data).then((res) => {
        sessionStorage.setItem('ngStorage-currentUser', JSON.stringify(res))
        commit('userInfo', res)
      })
    }
  }
}

export default user
